[PACKAGE]: ../../raw/master/mkp/cisco_eigrp-0.3.0-20230607.mkp "cisco_eigrp-0.3.0-20230607.mkp"
# Cisco EIGRP

Collection of Cisco EIGRP checks
*  *cisco_eigrp_as_info*: monitors the EIGRP AS status
*  *cisco_eigrp_interface*: monitors EIGRP enabled interfaces
*  *cisco_eigrp_peers*: monitors EIGRP peers (IPv4 only)
*  *cisco_eigrp_topology_table*: monitors the EIGRP topology table

---
### Download

* [Download latest mkp file][PACKAGE]

**Note**: before you update to a newer version, always check the [CHANGELOG](CHANGELOG). There might be incompatible changes.

---                   
### Installation

You can install the package by uploading it to your CheckMK site and as site user run 
```
mkp install PACKAGENAME-VERSION.mkp
```
or beginning with CMK2.2.x
```
mkp add PACKAGENAME-VERSION.mkp
mkp enable PACKAGENAME VERSION
```
In the non RAW editions of CheckMK you can use the GUI to install the package (_Setup_ -> _Extension Packages_ -> _Upload package_)

---
### Want to contribute?

Nice ;-) Have a look at the [contribution guidelines](CONTRIBUTING.md "Contributing")

---
### Check Info *cisco_eigrp_as_info*

* *service*: this check creates one service per EIGRP AS and address family
* *state*: **critical** if the EIGRP AS is not found
* *wato*: none
* *perfdata*: 
    * Neighbour count (count)
    * Hellos send (/s)
    * Hellos received (/s)
    * Updates send (count)
    * Updates received (count)
    * Alternate route queries send (count)
    * Alternate route queries received (count)
    * Reply packets send (count)
    * Reply packets received (count)
    * Acknowledgements send (count)
    * Acknowledgements received (count)
    * Highest number of packets in the input queue (count)
    * Packets dropped from the input queue (count)
    * Stuck in active (SIA) queries sent (count)
    * Stuck in active (SIA) queries received (count)
    * Routes in the topology table (count)
    * Outstanding replies expected to queries send (count)

#### Sample output

![sample output](img/sample_as_info.png?raw=true "sample [SHORT TITLE]")

---
### Check Info *cisco_eigrp_interface*

**Note**: the item name has been chaged to short interface names (Gigabitethernet0/0/0 bocomes Gi0/0/0)

* *service*: this check creates on service per EIGRP enabled interface, EIGRP AS and address family
* *state*:\
    **critical** 
    *  if no authentication is configured on the interface
    *  if the EIGRP enabled interface is not found

    **waring** 
    *  if the EIGRP MD5 authentication configured on the interface (move to hmac-sha-256)
* *wato*:
    * you can confgure on withch interface types the check should ignore the missing EIGRP authentication
    * you can configure the check outcome for none/md5 authentication. Default is *critical* for no authentication and *warning* for MD5 based authentication
* *perfdata*:
    * Peer count (count)
    * Reliable queue length (count)
    * Unreliable queue length (count)
    * Average smooth round trip time (ms)
    * Routing updates awaiting transmission (count)
    * Reliable multicasts send (count)
    * Unreliable multicasts send (count)
    * Unreliable unicasts send (count)
    * Reliable unicasts send (count)
    * Multicast exceptions received (count)
    * Conditional-Receive packets (count)
    * Suppressed acknowledgements (count)
    * Retransmissions send (count)
    * Out-of-sequence packets received (count)
 
**Note**: Loopbak interfaces will be ommited

#### Sample output

![sample output](img/sample_interface.png?raw=true "sample [SHORT TITLE]")

---
### Check Info *cisco_eigrp_peers*

* *service*: this check creates on service per EOGRP peer interface, EIGRP AS and VRF (IPv4 and IPv6)
* *state*:\
    **critical** if the EIGRP peer is not found
    **warning** if the EIGRP uptime less min uptime (default 86400 seconds)
* *wato*: **min uptime**: the time befor a peer is considered as stable, the default is 86400 seconds (1 day)
* *perfdata*:
    * Peer uptime (s)
    * Packets enqueued (count)
    * Retransmissions (count)
    * Retries (count)
    * Smooth round trip time (ms)
    * Retransmission timeout (ms)

#### Sample output

![sample output](img/sample_peers.png?raw=true "sample [SHORT TITLE]")

---
### Check Info *cisco_eigrp_topology_table*

* *service*: this check creates on service per EIGRP AS, address family and VRF
* *state*:\
    **critical** if the EIGRP table is not found\
    **warning** if SIA or active routes are found 
* *wato*: you can configure if the check should ignore SIA and/or active routes
* *perfdata*:
    * All routes (count)
    * Active routes (count)
    * Stuck in active (SIA) routes (count)
    * Connected routes (count)
    * Internal routes (count)
    * External routes (count)
    * Summary routes (count)
    * Static redistributed routes (count)
    * Inet address (count)

#### Sample output

![sample output](img/sample_topo_table.png?raw=true "sample [SHORT TITLE]")

