#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2017-12-27
#
# Check_MK cisco_eigrp_peer WATO plugin
#
from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    MonitoringState,
    ListChoice,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)

_ignore_interfaces_auth = [
    (6, 'Ethernet CSMAD'),
    (24, 'Loopback'),
    (53, 'Proprietary Virtual (Cisco VLAN L3)'),
    (131, 'Tunnel'),
    (135, 'Layer 2 VLAN',),
    (136, 'Layer 3 IP VLAN'),
]


def _parameter_valuespec_cisco_eigrp_interface():
    return Dictionary(
        help=_(''),
        elements=[
            ('ignore_interfaces_auth',
             ListChoice(
                 title=_('no warning if EIRGP authentication not configured on selected interface types'),
                 help=_('no warning if EIRGP authentication not configured on selected interface types'),
                 choices=_ignore_interfaces_auth,
                 default_value=[],
             )),
            ('no_auth_state',
             MonitoringState(
                 title=_('State to report when interface has no authentication configured'),
                 help=_(
                     'State if an EIGRP enabled interface has no authentication configured. Default is critical'),
                 default_value=2,
             ),
             ),

            ('md5_auth_state',
             MonitoringState(
                 title=_('State to report when interface uses MD5 authentication'),
                 help=_('State if an EIGRP enabled interface uses an MD5 hash as authentication method. '
                        'Default is warning'),
                 default_value=1,
             ),
             ),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_eigrp_interface',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Cisco EIGRP interface'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_eigrp_interface,
        title=lambda: _('Cisco EIGRP interface'),
    ))
